@@ -4,18 +4,18 @@ A comprehensive Python wrapper for TradeStation WebAPI v3, providing type-safe a
 to TradeStation's brokerage, order execution, and market data services.
 """
 
-from .client import TradeStationClient, HttpClient
-from .services import MarketDataService, BrokerageService, OrderExecutionService
+from .client import HttpClient, TradeStationClient
+from .services import BrokerageService, MarketDataService, OrderExecutionService
 from .utils.exceptions import (
     TradeStationAPIError,
     TradeStationAuthError,
+    TradeStationNetworkError,
     TradeStationRateLimitError,
     TradeStationResourceNotFoundError,
-    TradeStationValidationError,
-    TradeStationNetworkError,
     TradeStationServerError,
-    TradeStationTimeoutError,
     TradeStationStreamError,
+    TradeStationTimeoutError,
+    TradeStationValidationError,
 )
 
 __version__ = "1.2.0"
